package jdk.internal.event;

import sun.misc.SharedSecrets;
import java.time.Duration;
import java.util.Date;
import java.util.stream.Collectors;
import java.util.stream.IntStream;
import java.time.Instant;
import sun.util.logging.PlatformLogger;
import sun.misc.JavaUtilJarAccess;

public final class EventHelper
{
    private static final JavaUtilJarAccess JUJA;
    private static volatile boolean loggingSecurity;
    private static volatile PlatformLogger securityLogger;
    private static final PlatformLogger.Level LOG_LEVEL;
    private static final String SECURITY_LOGGER_NAME = "jdk.event.security";
    
    public EventHelper() {
    }
    
    public static void logTLSHandshakeEvent(Instant instant, String s, int i, String s2, String s3, long l) {
        assert EventHelper.securityLogger != null;
        EventHelper.securityLogger.fine(getDurationString(instant) + " TLSHandshake: {0}:{1}, {2}, {3}, {4}", new Object[] { s, Integer.valueOf(i), s3, s2, Long.valueOf(l) });
        return;
    }
    
    public static void logSecurityPropertyEvent(String s, String s2) {
        assert EventHelper.securityLogger != null;
        EventHelper.securityLogger.fine("SecurityPropertyModification: key:{0}, value:{1}", new Object[] { s, s2 });
        return;
    }
    
    public static void logX509ValidationEvent(int i, int[] values) {
        assert EventHelper.securityLogger != null;
        EventHelper.securityLogger.fine("ValidationChain: {0}, {1}", new Object[] { Integer.valueOf(i), (String)IntStream.of(values).mapToObj(Integer::toString).collect(Collectors.joining(", ")) });
        return;
    }
    
    public static void logX509CertificateEvent(String s, String s2, String s3, String s4, String s5, int i, long l, long date, long date2) {
        assert EventHelper.securityLogger != null;
        EventHelper.securityLogger.fine("X509Certificate: Alg:{0}, Serial:{1}, Subject:{2}, Issuer:{3}, Key type:{4}, Length:{5}, Cert Id:{6}, Valid from:{7}, Valid until:{8}", new Object[] { s, s2, s3, s4, s5, Integer.valueOf(i), Long.valueOf(l), new Date(date), new Date(date2) });
        return;
    }
    
    private static String getDurationString(Instant startInclusive) {
        if (startInclusive != null) {
            long n = Duration.between(startInclusive, Instant.now()).toNanos() / 1000L;
            if (n < 1000000L) {
                return "duration = " + (double)n / 1000.0 + " ms:";
            }
            return "duration = " + (double)(n / 1000L) / 1000.0 + " s:";
        }
        else {
            return "";
        }
    }
    
    public static boolean isLoggingSecurity() {
        if (EventHelper.securityLogger == null && !EventHelper.JUJA.isInitializing()) {
            PlatformLogger logger = PlatformLogger.getLogger("jdk.event.security");
            synchronized (EventHelper.class) {
                if (EventHelper.securityLogger == null) {
                    EventHelper.securityLogger = logger;
                    EventHelper.loggingSecurity = logger.isLoggable(EventHelper.LOG_LEVEL);
                }
            }
        }
        return EventHelper.loggingSecurity;
    }
    
    static {
        JUJA = SharedSecrets.javaUtilJarAccess();
        LOG_LEVEL = PlatformLogger.Level.FINE;
    }
}
